package
Version:
v0.0.0-...-9cc3d76
Opens a new window with list of versions in this module.
Published: Mar 31, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type PasswordStore struct {
ID int `json:"id"`
Link string `json:"link"`
UserName string `json:"userName"`
Password string `json:"password"`
Description string `json:"description"`
Master string `json:"master"`
}
type Users struct {
ID int `json:"id"`
Email string `json:"email"`
Password string `json:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.